# coding: utf-8
module BlsmVdCore
  class ClearingItem < BlsmVdCore::BaseRecord
    self.table_name='clearing_items'
    belongs_to :user, class_name: "::BlsmVdCore::User"
    belongs_to :order, class_name: "::BlsmVdCore::Order"
    belongs_to :clearing, class_name: "::BlsmVdCore::Clearing"

    after_update :keep_commit_changes
    after_commit :after_clearing_item_changed
    #物流服务费
    def express_service_fee
      if self.pay_type=='CODPAY'
        return 5
      end
      0
    end

    #可能的（预计）收入
    def possible_profit
      if self.state=='CASH_BACK'
        return sprintf('%0.2f', (self.real_amount - self.order_amount + self.earn_amount)* self.rate_of_profit - self.express_service_fee).to_f
      end
      sprintf('%0.2f', self.earn_amount * self.rate_of_profit - self.express_service_fee).to_f
    end

    #拒签
    def marking_refuse(note, reduce_real_amount = 0)
      update_params = {}
      update_params[:notes] = note
      update_params[:state] = 'CASH_BACK'
      if self.order.toggle_delivery_deposit && self.order.pay_type.to_i==1
        update_params[:real_amount] = self.express_service_fee - (self.earn_amount - self.order_amount) - reduce_real_amount
      else
        update_params[:real_amount] = self.express_service_fee - (self.earn_amount - self.order_amount + self.order.real_shipping_charge * 2) - reduce_real_amount
      end

      update_params.delete(:real_amount) if self.possible_profit < 0.0
      update_params[:rate_of_profit] = 1
      self.update_attributes(update_params)
    end

    #确认
    def marking_confirm(note)
      update_params = Hash.new
      update_params[:notes] = note
      update_params[:state] = 'CASH_BACK'
      update_params[:earn_amount] = self.order.jm_profit
      update_params[:real_amount] = ((self.order.toggle_delivery_deposit && self.order.pay_type.to_i==1) ? (self.order.actual_total.to_f+self.order.payment_total.to_f) : self.order.actual_total)
      self.update_attributes(update_params)
    end


    #发生改变之后，记住状态的变化
    def keep_commit_changes
      @committed_changes = self.changes
    end

    #订单发生变化
    def after_clearing_item_changed
      if @committed_changes && !@committed_changes.empty?
        BlsmVdCore.on_clearing_item_cash_back(self.id) if @committed_changes.has_key?('state') #物流返款等信息
        @committed_changes.clear
      end
    end
  end
end