# coding: utf-8
module BlsmVdCore
  class Order < BlsmVdCore::BaseRecord
    include BlsmVdCore::EncryptedId
    self.table_name='orders'
    has_many :clearing_items, class_name: "::BlsmVdCore::ClearingItem"
    has_many :line_items, class_name: "::BlsmVdCore::LineItem"
    belongs_to :application, class_name: "::BlsmVdCore::Application", foreign_key: "application_id"
    belongs_to :shippingorder, class_name: "::BlsmVdCore::Shippingorder", foreign_key: "shippingorder_id"
    belongs_to :ubox_vm, class_name: "::BlsmVdCore::UboxVm", foreign_key: 'ubox_vmid', primary_key: 'ubox_vmid'
    has_one :vd_free_post,class_name:  "::BlsmVdCore::VdFreePost"

    encrypted_id key: 'bYqILlFMZn3xd8Cy'

    public
    def get_vd_score(role)
      fee = 0.0
      if "black" == role
        self.line_items.each do |item|
          next if item.product_prop.nil?
          (fee += item.quantity * item.product_prop.black_integral ) if item.sale_price!=0
        end
      else
        self.line_items.each do |item|
          next if item.product_prop.nil?
          rate = item.product_prop.ordinary_rate
          rate = VdUserScore::SCORES[:SALE_OUT_DIRECT] if rate.nil? && "normal" == role
          (fee += ((item.quantity * item.franchise_price.to_f) * rate) ) if item.sale_price!=0
        end
      end
      sprintf('%0.2f', fee.to_f).to_f
    end

    #到付押金开关状态
    def toggle_delivery_deposit
      (self.toggle_setting.to_i & 0b00000001) == 1
    end

    #是否是自动售货机的订单
    def ubox_order?
      self.ubox_vm
    end

    def pay_off_line?
      self.pay_type == 1
    end

    def pay_on_line?
      !(self.pay_off_line?)
    end

    def number
      created_at.to_i.to_s + (id * 2 + 19871030).to_s
    end

    #加盟商（微店主）赚取的利润（直接利润）
    def jm_profit
      jm_cost = 0
      if self.line_items
        self.line_items.each do |item|
          unless item && item.franchise_price
            next
          end
          jm_cost += item.quantity * (item.franchise_price.to_f)
        end
      end
      ubox_order? ? sprintf('%0.2f', self.total_fee).to_f : sprintf('%0.2f', (self.total_fee - self.shipping_charge - jm_cost).to_f).to_f
    end

    #总的加盟费（供货价）
    def jm_fee
      fee = 0
      if self.line_items
        self.line_items.each do |item|
          fee += item.quantity * item.franchise_price.to_f
        end
      end
      sprintf('%0.2f', fee.to_f).to_f
    end

    #订单总金额
    def total_fee
      sprintf('%0.2f', (self.item_total + self.shipping_charge).to_f).to_f
    end

    #真实的运费
    def real_shipping_charge
      if self.shipping_charge > 0
        return self.shipping_charge
      end

      conn = Faraday.new(:url => 'http://'+"api.aihuo360.com")
      response = conn.get do |req|
        req.url '/v2/shipping_charges'
        req.params[:province] = self.shipping_province
        req.params[:city] = self.shipping_city
        req.params[:district] = self.shipping_district
      end
      begin
        result = JSON.parse(response.body)
        if self.pay_type==1
          result['shipping_charges'][0]['cash_on_delivery'].to_f
        else
          result['shipping_charges'][0]['pay_online'].to_f
        end
      rescue
        15
      end
    end

    private

    def self.valid_update?(clearing_item)
      if clearing_item[:state] == 'CASH_BACK'
        return false
      end
      return true
    end

    def self.latest_notes(clearing_item, user, action)
      notes = "#{user[:username] if user}"
      date_now = DateTime.parse(Time.now.to_s).strftime('%Y-%m-%d %H:%M:%S').to_s
      notes = (clearing_item[:notes] ? clearing_item[:notes]+'<br>' : '')+"#{date_now} #{notes} #{action}"
      return notes
    end

    alias :franchise_sum :jm_fee
  end
end